
% Replication of the published CUPS PASA class. 

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{pasa2}[2017/04/13, v2.0]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

\LoadClass[twoside,twocolumn,10pt]{article}

\RequirePackage{amsmath,amssymb}
\RequirePackage{etoolbox}
\RequirePackage[style]{abstract}
\RequirePackage{enumitem}
\RequirePackage[explicit]{titlesec}
\RequirePackage[T1]{fontenc}
\RequirePackage[tracking=smallcaps]{microtype}
\RequirePackage{lmodern}
\RequirePackage{caption}
\RequirePackage{fancyhdr}
\RequirePackage{xcolor}
\RequirePackage{sansmath}


\definecolor{titlecolorPASA}{RGB}{
% PASA blue:
% 0,50,153
0,0,0
}

\RequirePackage[letterpaper,top=.5in,includehead,headsep=14pt,headheight=28pt,left=.75in,textwidth=41.5pc,textheight=56pc,columnsep=18pt,footskip=18pt]{geometry}

\renewcommand{\title}[2][]{%
  \gdef\@shorttitle{#1}
  \gdef\@title{#2}
}

\renewcommand{\author}[2][]{%
  \gdef\@shortauthor{#1}
  \gdef\@author{#2}
}

\newcommand{\affil}[1]{\par\noindent\affilfont#1\par}


\def\@shortauthor{}
\def\@shorttitle{}
\def\@jyear{}
\def\@jnum{}
\def\@jid{}
\def\@jtitle{Publications of the Astronomical Society of Australia}
\def\@copyrightstatement{}
\def\@doi{}
\def\@documentstatus{}

\newcommand{\doi}[1]{\gdef\@doi{#1}}
\newcommand{\jyear}[1]{\gdef\@jyear{#1}}
\newcommand{\jid}[1]{\gdef\@jid{#1}}
\newcommand{\jtitle}[1]{\gdef\@jtitle{#1}}
\newcommand{\copyrightstatement}[1]{\gdef\@copyrightstatement{#1}}
\newcommand{\documentstatus}[1]{\gdef\@documentstatus{#1}}

\RequirePackage{environ}
\NewEnviron{frontmatter}{\twocolumn[\BODY]\saythanks}

\def\titlefont{\fontsize{18}{22}\selectfont\raggedright\sffamily}
\def\authorfont{\normalsize\rightskip5.5pc \sansmath\sffamily}
\def\affilfont{\scriptsize\raggedright\sansmath\sffamily}
\def\abstractfont{\small}
\def\keywordfont{\small}



%% Section
\def\sectionfont{\normalsize\bfseries\rightskip1pc plus1fill\mathversion{bold}\sansmath\sffamily\color{titlecolorPASA}}
\def\subsectionfont{\normalsize\bfseries\rightskip1pc plus1fill\mathversion{bold}\sansmath\sffamily\color{titlecolorPASA}}
\def\subsubsectionfont{\normalsize\itshape\rightskip1pc plus1fill\mathversion{normal}\sansmath\sffamily\color{titlecolorPASA}}
\def\paragraphfont{\normalsize\itshape\mathversion{normal}}%
\def\subparagraphfont{\normalsize}%
\def\subsubparagraphfont{\normalsize}%
\def\bibliofont{\small\color{titlecolorPASA}}
\def\tabnotefont{\footnotesize\sffamily}

\renewcommand{\@maketitle}{%
%   \rule{\linewidth}{.27pt}\vspace{11.5pt}
  {\titlefont\bfseries\large \textcolor{titlecolorPASA}{Research Paper}\par}
  \vskip15pt
  {\titlefont\textcolor{titlecolorPASA}{\sansmath\@title}\par}
  \vskip20pt
%   \rule{\linewidth}{.27pt}\vspace{11.5pt}
  {\authorfont\@author\par}
  \vskip7pt
}

\fancyhf{}
\pagestyle{fancy}
\renewcommand{\headrulewidth}{0pt}
\fancyhead[LE,RO]{\sffamily\thepage}
\fancyhead[LO]{\itshape\sffamily\@shorttitle}
\fancyhead[RE]{\itshape\sffamily\@shortauthor}
\fancypagestyle{plain}{%
  \fancyhf{}
  \lhead[L]{\footnotesize%
    \sffamily \textrm{\LaTeX}\ document typeset by the authors from a modified \textrm{\LaTeX}\ template from the \emph{\@jtitle}\ifdefempty{\@jid}{}{\space(\@jid)}.\\%
    Current document status: \textbf{\@documentstatus}.\\%
    % \ifdefempty{\@copyrightstatement}{}{\@copyrightstatement.\\}%
    % \ifdefempty{\@doi}{}{doi:\space\@doi.}%
  }
  \cfoot{\sffamily\thepage}
}

\renewcommand{\abstitlestyle}[1]{\textbf{\sffamily #1}}
\renewcommand{\abstractnamefont}{\bfseries\sffamily}
\renewcommand{\abstracttextfont}{\abstractfont}
\setlength{\absleftindent}{0pt}
\setlength{\absrightindent}{0pt}
\setlength{\absparindent}{0pt}
\apptocmd{\abstract}{\noindent\ignorespaces}{}{}
\appto{\endabstract}{\vskip12pt}

\newenvironment{keywords}{%
  \noindent\keywordfont\textbf{{\sffamily Keywords: }}%
}{\vskip10pt}

\DeclareCaptionFont{sfmath}{\sansmath}
\captionsetup*[figure]{font={footnotesize,sf,sfmath},labelfont=bf,labelsep=period,skip=10pt}
\captionsetup*[table]{font={footnotesize,sf,sfmath},position=top,labelfont=bf,labelsep=space,skip=10pt}


\newenvironment{acknowledgements}{\paragraph{\small\bfseries\textcolor{titlecolorPASA}{\sffamily Acknowledgements.}}\small}{}

\titleformat{\section}
  {\sectionfont}
  {\thesection.}
  {0.5em}
  {\textcolor{titlecolorPASA}{#1}}
\titleformat{\subsection}
  {\subsectionfont}
  {\thesubsection.}
  {0.5em}
  {\textcolor{titlecolorPASA}{\textit{#1}}}

\titleformat{\subsubsection}
  {\subsubsectionfont}
  {\thesubsubsection.}
  {0.5em}
  {\textcolor{titlecolorPASA}{#1}}

\titleformat{\paragraph}[runin]
  {\paragraphfont}
  {\theparagraph}
  {0.5em}
  {#1}
  
\titlespacing*{\section}{0pt}{18pt}{6pt}
\titlespacing*{\subsection}{0pt}{18pt}{6pt}
\titlespacing*{\subsubsection}{0pt}{10pt}{2pt}
\titlespacing*{\paragraph}{0pt}{6pt}{.5em}


\apptocmd{\quotation}{\setlength{\parindent}{0pt}%
\noindent\ignorespaces}{}{}
\patchcmd{\quotation}{\rightmargin\leftmargin}{\rightmargin0pt}{}{}
\setlist{noitemsep}
\newlist{unnumlist}{itemize}{1}
\setlist[unnumlist]{label={},leftmargin=2em,itemindent=-1em}

\def\x{@{\extracolsep{\fill}}}

\newcommand{\tabnote}[1]{\par\vskip1pt{\raggedright\tabnotefont #1\par}}

\RequirePackage{natbib}
\setlength{\bibsep}{0.3mm}

\makeatletter

% https://tex.stackexchange.com/a/27311
% Patch case where name and year are separated by aysep
\patchcmd{\NAT@citex}
  {\@citea\NAT@hyper@{%
     \NAT@nmfmt{\NAT@nm}%
     \hyper@natlinkbreak{\NAT@aysep\NAT@spacechar}{\@citeb\@extra@b@citeb}%
     \NAT@date}}
  {\@citea\NAT@nmfmt{\NAT@nm}%
   \NAT@aysep\NAT@spacechar\NAT@hyper@{\NAT@date}}{}{}

% Patch case where name and year are separated by opening bracket
\patchcmd{\NAT@citex}
  {\@citea\NAT@hyper@{%
     \NAT@nmfmt{\NAT@nm}%
     \hyper@natlinkbreak{\NAT@spacechar\NAT@@open\if*#1*\else#1\NAT@spacechar\fi}%
       {\@citeb\@extra@b@citeb}%
     \NAT@date}}
  {\@citea\NAT@nmfmt{\NAT@nm}%
   \NAT@spacechar\NAT@@open\if*#1*\else#1\NAT@spacechar\fi\NAT@hyper@{\NAT@date}}
  {}{}

\makeatother

\frenchspacing

\endinput